@@ -99,7 +99,9 @@ class FinanceTransact(generics.UpdateAPIView):  # 或继承(APIView)
 
     def finance_flow_writing(self):
         params = parse_data(self)
-        data, err_txt = FinanceTransactService.finance_flow_writing(params, "RECHARGE")
+        # print(params)
+        data, err_txt = FinanceTransactService.finance_flow_writing(params=params,
+                                                                    finance_type='PAY')
         if err_txt is None:
             return util_response(data=data)
         return util_response(err=47767, msg=err_txt)
