@@ -115,3 +115,21 @@ class FinanceTransacts(generics.UpdateAPIView):  # 或继承(APIView)
         if err_txt is None:
             return util_response(data=data)
         return util_response(err=47767, msg=err_txt)
+
+    # 大额转账
+    def large_transfer(self):
+        token = self.META.get('HTTP_AUTHORIZATION', '')
+        if not token:
+            return util_response(err=4001, msg='缺少Token')
+
+        # print("get token:", token)
+        data, err_txt = UserService.check_token(token)
+        # print("get data, err_txt:", data, err_txt)
+        if not data:
+            return util_response(err=4002, msg=err_txt)
+        params = parse_data(self)
+        params['account_id'] = data['user_id']
+        data, err_txt = FinanceTransactsService.large_transfer(params)
+        if err_txt is None:
+            return util_response(data=data)
+        return util_response(err=47767, msg=err_txt)
