@@ -37,6 +37,7 @@ class SandBox(models.Model):
     sand_box_name = models.CharField(verbose_name='沙盒名称', max_length=128)
     sand_box_label = models.CharField(verbose_name='沙盒标签', max_length=128)
     description = models.CharField(verbose_name='描述', max_length=128)
+    config = models.JSONField(verbose_name='前端配置')
 
     class Meta:
         db_table = 'finance_sandbox'
@@ -146,6 +147,7 @@ class Transact(models.Model):
 class StatusCode(models.Model):
     id = models.AutoField(verbose_name='ID', primary_key=True)
     finance_status_code = models.CharField(verbose_name='资金状态码', max_length=128)
+    finance_status_name = models.CharField(verbose_name='资金状态名', max_length=128)
     description = models.CharField(verbose_name='描述', max_length=128)
 
     class Meta:
