@@ -232,6 +232,11 @@ class FinanceService:
         if search_word:
             query_dict['summary__icontains'] = search_word
 
+        # 精确匹配沙盒状态
+        sand_box_status_code = params.get('sand_box_status_code', '')
+        if sand_box_status_code:
+            query_dict['sand_box_status_code'] = sand_box_status_code
+
         return {'err': 0, 'msg': 'OK', 'query_dict': query_dict, }
 
     #
