@@ -1,4 +1,8 @@
+import decimal
+import json
 import sys
+import time
+from datetime import timedelta
 from pathlib import Path
 from decimal import Decimal
 import math
@@ -14,7 +18,7 @@ from main.settings import BASE_DIR
 from xj_user.models import BaseInfo
 from xj_user.services.user_platform_service import UserPlatformService
 from .finance_service import FinanceService
-from ..models import Transact, Currency, PayMode, SandBox
+from ..models import Transact, Currency, PayMode, SandBox, StatusCode
 from ..utils.jt import Jt
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
@@ -36,6 +40,26 @@ sand_box_receivable = finance_main_config_dict.sand_box_receivable or finance_mo
 sand_box_cash_withdrawal = finance_main_config_dict.sand_box_receivable or finance_module_config_dict.sand_box_cash_withdrawal or ""
 
 
+class DateEncoder(json.JSONEncoder):
+    def default(self, obj):
+        try:
+            if isinstance(obj, int):
+                return int(obj)
+            elif isinstance(obj, float) or isinstance(obj, decimal.Decimal):
+                return float(obj)
+            if isinstance(obj, datetime):
+                return obj.strftime("%Y-%m-%d %H:%M:%S")
+            elif isinstance(obj, datetime.date):
+                return obj.strftime('%Y-%m-%d')
+            if isinstance(obj, time) or isinstance(obj, timedelta):
+                return obj.__str__()
+            else:
+                return json.JSONEncoder.default(self, obj)
+        except Exception as e:
+            # logger.exception(e, stack_info=True)
+            return obj.__str__()
+
+
 # 声明用户序列化
 class UserSerializer(serializers.ModelSerializer):
     def create(self, validated_data):
@@ -105,7 +129,8 @@ class FinanceTransactSerializer(serializers.ModelSerializer):
             'pay_info',
             'finance_status_code',
             'sand_box_status_code',
-            'snapshot'
+            'snapshot',
+            'goods_info',
         ]
 
     def get_lend(self, obj):
@@ -180,68 +205,115 @@ class FinanceTransactService:
         return transact, None
 
     @staticmethod
-    def finance_flow_writing(params, fund_type=None):
+    def finance_flow_writing(params, finance_type=None):
 
         amount = params.get('amount', 0.0)  # 如果是负数是应付反之是应收
-        if not amount:
-            return None, "金额不能为空"
-        transact_no = params.get('transact_no', "")  # 订单号
+        enroll_id = params.get('enroll_id', None)  # 报名id
+        order_no = params.get('order_no', None)  # 订单号
+        summary = params.get('summary', None)  # 摘要
+        transact_no = params.get('transact_no', None)  # 订单号
+        account_id = params.get("account_id", None)
+        pay_mode = params.get("pay_mode", None)
+        goods_info = params.get("goods_info", None)
+        sand_box_status_code = params.get("sand_box_status_code", None)
+        currency = params.get("currency", "CNY")
+        images = params.get("images", "")
         user_finance_data = {
-            'their_account_id': params.get("user_id", ""),
+            'account_id': account_id,
             'their_account_name': sub_appid,
-            'currency': "CNY",
-            'pay_mode': params.get("pay_mode", ""),
+            'currency': currency,
+            'pay_mode': pay_mode,
+            'platform': merchant_name,
         }
 
         platform_finance_data = {
             'account_name': sub_appid,
-            'their_account_id': params.get("user_id", ""),
-            'currency': "CNY",
-            'pay_mode': params.get("pay_mode", ""),
+            'their_account_id': account_id,
+            'currency': currency,
+            'pay_mode': pay_mode,
+            'platform': merchant_name,
 
         }
-        if fund_type == "RECHARGE":  # 充值行为
-            platform_finance_data['amount'] = float(amount)
-            platform_finance_data['transact_no'] = str(transact_no) + "-2",
-            platform_finance_data['finance_status_code'] = 5  # 资金状态码 finance_status_code 124 已下单支付 待接单
-            finance_add_data, err_txt = FinanceTransactService.post(platform_finance_data)
+        # 判断金额
+        if not amount:
+            return None, "金额不能为空"
+        # 判断是否接收报名id
+        if enroll_id:
+            user_finance_data['enroll_id'] = enroll_id
+            platform_finance_data['enroll_id'] = enroll_id
+        # 判断是否接收订单号
+        if order_no:
+            user_finance_data['order_no'] = order_no
+            platform_finance_data['order_no'] = order_no
+        if summary:
+            summary_content = "【" + summary['payer'] + "】支付 【" + summary['payee'] + "】项目名称【" + summary[
+                'entry_name'] + "】款项"
+            user_finance_data['summary'] = summary_content
+            platform_finance_data['summary'] = summary_content
+        #
+        if goods_info:
+            user_finance_data['goods_info'] = goods_info
+            platform_finance_data['goods_info'] = goods_info
+        if sand_box_status_code:
+            user_finance_data['sand_box_status_code'] = sand_box_status_code
+            platform_finance_data['sand_box_status_code'] = sand_box_status_code
+        if images:
+            user_finance_data['images'] = images
+            platform_finance_data['images'] = images
 
-            if err_txt:
-                return None, err_txt
-            user_finance_data['amount'] = -abs(float(amount))
-            user_finance_data['transact_no'] = str(transact_no) + "-1",
-            user_finance_data['finance_status_code'] = 5  # 资金状态码 finance_status_code 124 已下单支付 待接单
-            # user_add_data, user_err_txt = FinanceTransactService.post(user_finance_data)
-            # if user_err_txt:
-            #     return None, user_err_txt
+        if finance_type == "RECHARGE":  # 充值行为
+            try:
+                user_finance_data['amount'] = -abs(float(amount))
+                user_finance_data['transact_no'] = str(transact_no) + "-1"
+                user_finance_data['finance_status_name'] = "待接单"  # 资金状态码 finance_status_code 43 已下单支付 待接单
+                user_add_data, user_err_txt = FinanceTransactService.post(user_finance_data)
+                if user_err_txt:
+                    print(">>>>payment_logic_processing_err", user_err_txt)
+                    # logger.info(">>>>payment_logic_processing" + "写入资金模块失败")
+                    return None, user_err_txt
+                platform_finance_data['amount'] = float(amount)
+                platform_finance_data['transact_no'] = str(transact_no) + "-2"
+                platform_finance_data['finance_status_name'] = "待接单"  # 资金状态码 finance_status_code 43 已下单支付 待接单
+                finance_add_data, err_txt = FinanceTransactService.post(platform_finance_data)
+                if err_txt:
+                    return None, err_txt
+                return None, None
+            except Exception as e:
+                return None, str(e)
 
-            print(">>>>platform_finance_data", platform_finance_data)
-            print(">>>>user_finance_data", user_finance_data)
-        elif fund_type == "PAY":
-            platform_finance_data['sand_box'] = sand_box_meet  # 沙盒应付
-            platform_finance_data['amount'] = -abs(float(amount))
-            platform_finance_data['order_no'] = FinanceService.make_unicode()
-            platform_finance_data['transact_no'] = FinanceService.make_unicode(
-                str(platform_finance_data['account_name']))
-            platform_finance_data['finance_status_code'] = 2  # 资金状态码 finance_status_code 242 报名成功 待付款
-            finance_add_data, err_txt = FinanceTransactService.post(platform_finance_data)
-            if err_txt:
-                return None, err_txt
-            user_finance_data['sand_box'] = sand_box_receivable  # 沙盒应收
-            user_finance_data['amount'] = float(amount)
-            user_finance_data['order_no'] = FinanceService.make_unicode()
-            user_finance_data['transact_no'] = FinanceService.make_unicode(str(user_finance_data['account_id']))
-            user_finance_data['finance_status_code'] = 2  # 资金状态码 finance_status_code 242 报名成功 待付款
-            user_add_data, user_err_txt = FinanceTransactService.post(user_finance_data)
-            if user_err_txt:
-                return None, user_err_txt
-        elif fund_type == "WITHDRAW":
+        elif finance_type == "PAY":  # 支付行为
+            try:
+                user_finance_data['sand_box'] = sand_box_receivable  # 沙盒应收
+                user_finance_data['amount'] = float(amount)
+                user_finance_data['order_no'] = FinanceService.make_unicode()
+                user_finance_data['transact_no'] = FinanceService.make_unicode(str(user_finance_data['account_id']))
+                user_finance_data['finance_status_name'] = "待付款"  # 资金状态码 finance_status_code 242 报名成功 待付款
+                user_add_data, user_err_txt = FinanceTransactService.post(user_finance_data)
+                # print(user_finance_data)
+                if user_err_txt:
+                    return None, user_err_txt
+                platform_finance_data['sand_box'] = sand_box_meet  # 沙盒应付
+                platform_finance_data['amount'] = -abs(float(amount))
+                platform_finance_data['order_no'] = FinanceService.make_unicode()
+                platform_finance_data['transact_no'] = FinanceService.make_unicode(
+                    str(platform_finance_data['account_name']))
+                platform_finance_data['finance_status_name'] = "待付款"  # 资金状态码 finance_status_code 242 报名成功 待付款
+                finance_add_data, err_txt = FinanceTransactService.post(platform_finance_data)
+                if err_txt:
+                    return None, err_txt
+                return None, None
+            except Exception as e:
+                return None, str(e)
+        elif finance_type == "WITHDRAW":  # 提现行为
             user_finance_data['sand_box'] = sand_box_cash_withdrawal  # 提现
             user_finance_data['amount'] = -abs(float(amount))
             user_finance_data['order_no'] = FinanceService.make_unicode()
             finance_add_data, err_txt = FinanceTransactService.post(user_finance_data)
             if err_txt:
                 return None, None
+            return None, None
+        else:
+            return None, "资金类型不存在"
 
     @staticmethod
     def post(param):
@@ -317,7 +389,6 @@ class FinanceTransactService:
         # 边界检查，自己不能和自己交易
         # if account_id == their_account_id:
         #     return None, '自己不能和自己交易'
-
         # 生成发起交易的用户名 todo 要不用金额会不会更安全？怎么处理重复的可能性
         username = item['account'].user_name
         # 生成唯一且不可重复的交易ID，且具有校验作用
@@ -386,9 +457,9 @@ class FinanceTransactService:
             outgo = Decimal(math.fabs(amount)) if amount < 0 else Decimal(0.0)
             item['outgo'] = outgo
         else:
-            income = param.get('income', '')
+            income = Decimal(param.get('income ', 0.0))
             item['income'] = income
-            outgo = param.get('outgo', '')
+            outgo = Decimal(param.get('outgo', 0.0))
             item['outgo'] = outgo
 
         enroll_id = param.get('enroll_id', '')
@@ -396,7 +467,23 @@ class FinanceTransactService:
             item['enroll_id'] = enroll_id
 
         if param.get('finance_status_code', ''):
-            item['finance_status_code'] = param.get('finance_status_code', '')
+            # item['status_code_set'] = StatusCode.objects.filter(
+            #     id=param.get('finance_status_code', '')).first()
+            # if item['status_code_set'] is None:
+            #     return None, 'status_code不存在'
+            # item['finance_status_code'] = item['status_code_set'].id
+            item['status_code_set'] = StatusCode.objects.filter(
+                finance_status_code=param.get('finance_status_code', '')).first()
+            if item['status_code_set'] is None:
+                return None, 'status_code不存在'
+            item['finance_status_code'] = item['status_code_set'].finance_status_code
+        elif not param.get('finance_status_code', '') and param.get('finance_status_name', ''):
+            item['status_code_set'] = StatusCode.objects.filter(
+                finance_status_name=param.get('finance_status_name', '')).first()
+            if item['status_code_set'] is None:
+                return None, 'status_code不存在'
+            # item['finance_status_code'] = item['status_code_set'].id
+            item['finance_status_code'] = item['status_code_set'].finance_status_code
 
         if param.get('sand_box_status_code', ""):
             item['sand_box_status_code'] = param.get('sand_box_status_code', "")
@@ -430,16 +517,25 @@ class FinanceTransactService:
         if thread_id:
             item['thread_id'] = thread_id
         # 快照
-        snapshot = param.get('snapshot', '')
-        if snapshot:
-            item['snapshot'] = snapshot
+        goods_info = param.get('goods_info', '')
+        if goods_info:
+            jsDumps = json.dumps(goods_info, cls=DateEncoder)
+            jsLoads = json.loads(jsDumps)
             enroll_list = []
-            for i in snapshot['data']:
-                enroll_list.append(i['id'])
-            if not sys.modules.get("xj_enroll.service.enroll_services.EnrollServices"):
-                from xj_enroll.service.enroll_services import EnrollServices
-            EnrollServices.enroll_edit(params={"finance_invoicing_code": "Invoicing"},
-                                       search_param={"enroll_id_list": enroll_list})
+            if 'enroll' in jsLoads:
+                if not sys.modules.get("xj_enroll.service.enroll_services.EnrollServices"):
+                    from xj_enroll.service.enroll_services import EnrollServices
+                if isinstance(goods_info['enroll'], dict):
+                    EnrollServices.enroll_edit(params={"finance_invoicing_code": "Invoicing"},
+                                               search_param={"enroll_id": goods_info['enroll']['id']})
+                else:
+                    for i in goods_info['enroll']:
+                        enroll_list.append(int(i['id']))
+                    EnrollServices.enroll_edit(params={"finance_invoicing_code": "Invoicing"},
+                                               search_param={"enroll_id_list": enroll_list})
+            else:
+                print('不存在')
+        item['goods_info'] = jsLoads
 
         # 如果有沙盒。
         if item['sand_box']:
@@ -464,14 +560,21 @@ class FinanceTransactService:
         item['opposite_account'] = opposite_account
 
         # 摘要
-        item['summary'] = "摘要"
+        item['summary'] = "摘要...."
         summary = param.get('summary', '')
         if summary:
             item['summary'] = summary
+        elif not summary and param.get("sand_box_status_code", ""):
+            if param.get("sand_box_status_code", "") == "Invoicing":
+                item['summary'] = "开票"
+            elif param.get("sand_box_status_code", "") == "withdrawing":
+                item['summary'] = "提现"
+            elif param.get("sand_box_status_code", "") == "transfering":
+                item['summary'] = "转账"
 
-        # 商品信息
-        goods_info = param.get('goods_info', '')
-        item['goods_info'] = goods_info
+        # # 商品信息
+        # goods_info = param.get('goods_info', '')
+        # item['goods_info'] = goods_info
 
         # 支付信息
         pay_info = param.get('pay_info', '')
@@ -532,8 +635,10 @@ class FinanceTransactService:
 
         # 如果有id，则是修改数据
         if is_create:
+            # print()
             response = FinanceTransactService.create(item)
         else:
+            # print()
             response = FinanceTransactService.update(item)
         # return None
         return response
@@ -541,7 +646,6 @@ class FinanceTransactService:
     # 增
     @staticmethod
     def create(item):
-        # print(">>> create:", item, )
         # 增加一个交易记录
         serializer = FinanceTransactSerializer(data=item, context={})
 
@@ -567,7 +671,9 @@ class FinanceTransactService:
         serializer.validated_data['finance_status_code'] = item.get('finance_status_code', None)
         serializer.validated_data['thread_id'] = item.get('thread_id', None)
         serializer.validated_data['sand_box_status_code'] = item.get('sand_box_status_code', None)
-        serializer.validated_data['snapshot'] = item.get('snapshot', None)
+        serializer.validated_data['goods_info'] = item.get('goods_info', None)
+        serializer.validated_data['images'] = item.get('images', None)
+
 
         # print(">>> serializer.validated_data: ", serializer.validated_data,)
         # print(">>> serializer: ", serializer,)
@@ -598,19 +704,19 @@ class FinanceTransactService:
             # return Response({'err': 1019, 'msg': update_serializer.errors, })
             return None, update_serializer.errors
         # 验证成功，获取数据
-        update_serializer.validated_data['platform_id'] = item['platform_id']
+        update_serializer.validated_data['platform_id'] = item.get('platform_id', None)
         update_serializer.validated_data['account'] = item['account']
         update_serializer.validated_data['enroll_id'] = item.get('enroll_id', None)
-        update_serializer.validated_data['their_account'] = item['their_account']
+        update_serializer.validated_data['their_account'] = item.get('their_account', None)
         update_serializer.validated_data['pay_mode'] = item['pay_mode_set']
         update_serializer.validated_data['currency'] = item['currency_set']
         update_serializer.validated_data['sand_box'] = item.get('sand_box_set', None)
-        update_serializer.validated_data['income'] = item['income']
-        update_serializer.validated_data['outgo'] = item['outgo']
+        update_serializer.validated_data['income'] = item.get('income', None)
+        update_serializer.validated_data['outgo'] = item.get('outgo', None)
         update_serializer.validated_data['balance'] = item['balance']
         update_serializer.validated_data['transact_time'] = item['transact_time']
+        update_serializer.validated_data['images'] = item.get('images', None)
         # update_serializer.validated_data['sand_box_type_status'] = item.get('sand_box_type_status', None)
-
         update_serializer.save()
 
         FinanceService.check_balance(account_id=item['account'].id,
