@@ -102,7 +102,7 @@ class FinanceTransactsSerializer(serializers.ModelSerializer):
             'amount',
             'balance',
             'pay_mode',
-            # 'goods_info',
+            'goods_info',
             # 'pay_info',
             'sand_box',
             'remark',
@@ -112,7 +112,7 @@ class FinanceTransactsSerializer(serializers.ModelSerializer):
             'is_write_off',
             'finance_status_code',
             "sand_box_status_code",
-            "snapshot"
+            # "snapshot"
         ]
 
     # def get_order(self, obj):
@@ -254,7 +254,7 @@ class FinanceTransactsService:
 
         if order_no:
             transact_filter_obj = transact_obj.filter(
-                order_no=order_no, sand_box__isnull=False).values("order_no", "transact_no",
+                order_no=order_no, sand_box__isnull=False).values("order_no", "transact_no", "goods_info",
                                                                   "account_id",
                                                                   "enroll_id",
                                                                   "their_account_id",
@@ -355,6 +355,7 @@ class FinanceTransactsService:
     def write_off(params):
         order_no = params.get("order_no", "")
         type = params.get("type", "")
+        images = params.get("images", "")
         finance_transact_data, err = FinanceTransactsService.detail_all(order_no=order_no)
         if err:
             return None, err
@@ -379,6 +380,38 @@ class FinanceTransactsService:
                     # 生成真实记录成功后 原沙盒记录改为核销 并把提现状态改成 已提现
                 Transact.objects.filter(transact_no=transact_no).update(is_write_off=1, sand_box_status_code="withdrew",
                                                                         is_reverse=None)  # 沙盒核销
+            elif type == "transfered":
+
+                v['transact_no'] = FinanceService.make_unicode(str(transact_no))  # 流水号
+                if not sys.modules.get("xj_enroll.service.enroll_services.EnrollServices"):
+                    from xj_enroll.service.enroll_services import EnrollServices
+                    pay_call_back_data, pay_call_back_err = EnrollServices.bxtx_pay_call_back(v['order_no'])
+                    if pay_call_back_err:
+                        logger.info(">>>>报名修改失败" + pay_call_back_err)
+                    else:
+                        finance_status_code = pay_call_back_data
+                        print(pay_call_back_data)
+                v['finance_status_code'] = finance_status_code
+                # v['images'] = images
+                finance_transact, post_err = FinanceTransactService.post(v)
+                if post_err:
+                    return None, post_err
+                # 生成真实记录成功后 原沙盒记录改为核销
+                Transact.objects.filter(transact_no=transact_no).update(
+                    finance_status_code=finance_status_code,
+                    sand_box_status_code="transfered",
+                    is_write_off=1,
+                    is_reverse=None)  # 沙盒核销
+            elif type == "refuse":
+
+                # v['transact_no'] = FinanceService.make_unicode(str(transact_no))  # 流水号
+                v['images'] = images
+                # 生成真实记录成功后 原沙盒记录改为核销
+                Transact.objects.filter(transact_no=transact_no).update(
+                    finance_status_code=615,
+                    is_reverse=None)  # 沙盒核销
+
+
         return None, None
 
     @staticmethod
@@ -473,23 +506,43 @@ class FinanceTransactsService:
     @staticmethod
     def invoicing_approval(params):
         finance_id = params.get("finance_id", None)
+        transact_no = params.get("transact_no", None)
         if not finance_id:
             return None, "id不能为空"
         finance = Transact.objects.filter(id=finance_id)
         finance_data = finance.first()
         finance_data = model_to_dict(finance_data)
-        snapshot = finance_data['snapshot']
+        goods_info = finance_data['goods_info']
         enroll_list = []
-        for i in snapshot['data']:
-            enroll_list.append(i['id'])
-        # enroll_list = FinanceTransactsService.get_json_primary_key(snapshot)
-        if not sys.modules.get("xj_enroll.service.enroll_services.EnrollServices"):
-            from xj_enroll.service.enroll_services import EnrollServices
-        EnrollServices.enroll_edit(params={"finance_invoicing_code": "Invoiced"},
-                                   search_param={"enroll_id_list": enroll_list})
+        jsDumps = json.dumps(goods_info['goods_info'])
+        jsLoads = json.loads(jsDumps)
+        if 'enroll' in jsLoads:
+            for i in goods_info['goods_info']['enroll']:
+                enroll_list.append(i['id'])
+            # enroll_list = FinanceTransactsService.get_json_primary_key(snapshot)
+            if not sys.modules.get("xj_enroll.service.enroll_services.EnrollServices"):
+                from xj_enroll.service.enroll_services import EnrollServices
+            EnrollServices.enroll_edit(params={"finance_invoicing_code": "Invoiced"},
+                                       search_param={"enroll_id_list": enroll_list})
 
-        finance.update(sand_box_status_code="Invoiced")  # 沙盒核销
-        # print(enroll_list)
+            finance.update(sand_box_status_code="Invoiced", transact_no=transact_no)  # 沙盒核销
+
+        return None, None
+
+    @staticmethod
+    def large_transfer(params):
+        # print(params)
+        finance, err_txt = FinanceTransactService.finance_flow_writing(params=params, finance_type='PAY')
+        if err_txt:
+            return None, err_txt
+        return None, None
+
+    @staticmethod
+    def large_transfer(params):
+        # print(params)
+        finance, err_txt = FinanceTransactService.finance_flow_writing(params=params, finance_type='PAY')
+        if err_txt:
+            return None, err_txt
         return None, None
 
     # @staticmethod
